diff --git a/CMakeLists.txt b/CMakeLists.txt
index 7b4a2cb33..4a209fcaf 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -227,8 +227,14 @@ endif(NOT LINUX_DISTRIBUTION)
if(${CMAKE_SYSTEM_NAME} MATCHES "Darwin")
set(OperatingSystem "Mac OS X")
set(OS_IS_MACOSX TRUE)
- exec_program(uname ARGS -v OUTPUT_VARIABLE DARWIN_VERSION)
+ execute_process(COMMAND uname -v OUTPUT_VARIABLE DARWIN_VERSION)
string(REGEX MATCH "[0-9]+" DARWIN_VERSION ${DARWIN_VERSION})
+ if(${DARWIN_VERSION} MATCHES "18")
+ set(MACOS_MOJAVE TRUE)
+ set(CMAKE_XCODE_ATTRIBUTE_CLANG_CXX_LANGUAGE_STANDARD "c++14")
+ set(CMAKE_XCODE_ATTRIBUTE_CLANG_CXX_LIBRARY "libc++")
+ message(STATUS "Configuring GNSS-SDR v${VERSION} to be built on macOS Mojave 10.14")
+ endif(${DARWIN_VERSION} MATCHES "18")
if(${DARWIN_VERSION} MATCHES "17")
set(MACOS_HIGH_SIERRA TRUE)
set(CMAKE_XCODE_ATTRIBUTE_CLANG_CXX_LANGUAGE_STANDARD "c++14")
diff --git a/README.md b/README.md
index f2fe4a607..6624d618d 100644
--- a/README.md
+++ b/README.md
@@ -64,10 +64,10 @@ $ sudo apt-get install build-essential cmake git libboost-dev libboost-date-time
libboost-system-dev libboost-filesystem-dev libboost-thread-dev libboost-chrono-dev \
libboost-serialization-dev liblog4cpp5-dev libuhd-dev gnuradio-dev gr-osmosdr \
libblas-dev liblapack-dev libarmadillo-dev libgflags-dev libgoogle-glog-dev \
- libgnutls-openssl-dev libpcap-dev python-mako python-six libmatio-dev googletest
+ libgnutls-openssl-dev libpcap-dev python-mako python-six libmatio-dev libgtest-dev
~~~~~~
-Please note that `googletest` was named `libgtest-dev` in distributions older than Debian 9 "stretch" and Ubuntu 17.04 "zesty".
+Please note that the required files from `libgtest-dev` were moved to `googletest` in Debian 9 "stretch" and Ubuntu 18.04 "bionic", and moved back again to `libgtest-dev` in Debian 10 "buster" and Ubuntu 18.10 "cosmic".
**Note for Ubuntu 14.04 LTS "trusty" users:** you will need to build from source and install GNU Radio manually, as explained below, since GNSS-SDR requires `gnuradio-dev` >= 3.7.3, and Ubuntu 14.04 came with 3.7.2. Install all the packages above BUT EXCEPT `libuhd-dev`, `gnuradio-dev` and `gr-osmosdr` (and remove them if they are already installed in your machine), and install those dependencies using PyBOMBS. The same applies to `libmatio-dev`: Ubuntu 14.04 came with 1.5.2 and the minimum required version is 1.5.3. Please do not install the `libmatio-dev` package and install `libtool`, `automake` and `libhdf5-dev` instead. A recent version of the library will be downloaded and built automatically if CMake does not find it installed.
@@ -516,10 +516,7 @@ More details can be found in our tutorial about [GNSS-SDR configuration options
macOS and Mac OS X
---------
-
-### macOS 10.13 (High Sierra) and 10.12 (Sierra), Mac OS X 10.11 (El Capitan), 10.10 (Yosemite) and 10.9 (Mavericks).
-
-If you still have not installed [Xcode](https://developer.apple.com/xcode/ "Xcode"), do it now from the App Store (it's free). You will also need the Xcode Command Line Tools. Launch the Terminal, found in /Applications/Utilities/, and type:
+GNSS-SDR can be built on MacOS or Mac OS X, starting from 10.9 (Mavericks) and including 10.14 (Mojave). If you still have not installed [Xcode](https://developer.apple.com/xcode/ "Xcode"), do it now from the App Store (it's free). You will also need the Xcode Command Line Tools. Launch the Terminal, found in /Applications/Utilities/, and type:
~~~~~~
$ xcode-select --install
@@ -558,7 +555,7 @@ You also might need to activate a Python installation. The list of installed ver
$ port select list python
~~~~~~
-and you can activate a certain version (2.7 works well) by typing:
+and you can activate a certain version by typing:
~~~~~~
$ sudo port select --set python python27
diff --git a/cmake/cmake_uninstall.cmake.in b/cmake/cmake_uninstall.cmake.in
index 5d4ab76f7..9b3887185 100644
--- a/cmake/cmake_uninstall.cmake.in
+++ b/cmake/cmake_uninstall.cmake.in
@@ -24,10 +24,10 @@ string(REGEX REPLACE "\n" ";" files "${files}")
foreach(file ${files})
message(STATUS "Uninstalling $ENV{DESTDIR}${file}")
if(IS_SYMLINK "$ENV{DESTDIR}${file}" OR EXISTS "$ENV{DESTDIR}${file}")
- exec_program(
- "@CMAKE_COMMAND@" ARGS "-E remove \"$ENV{DESTDIR}${file}\""
+ execute_process(
+ COMMAND @CMAKE_COMMAND@ -E remove \"$ENV{DESTDIR}${file}\"
OUTPUT_VARIABLE rm_out
- RETURN_VALUE rm_retval
+ RESULT_VARIABLE rm_retval
)
if(NOT "${rm_retval}" STREQUAL 0)
message(FATAL_ERROR "Problem when removing $ENV{DESTDIR}${file}")
diff --git a/src/algorithms/PVT/adapters/rtklib_pvt.cc b/src/algorithms/PVT/adapters/rtklib_pvt.cc
index 509d07886..3e63a19a6 100644
--- a/src/algorithms/PVT/adapters/rtklib_pvt.cc
+++ b/src/algorithms/PVT/adapters/rtklib_pvt.cc
@@ -133,18 +133,6 @@ RtklibPvt::RtklibPvt(ConfigurationInterface* configuration,
{
rtcm_msg_rate_ms[k] = rtcm_MT1097_rate_ms;
}
- // getting names from the config file, if available
- // default filename for assistance data
- const std::string eph_default_xml_filename = "./gps_ephemeris.xml";
- const std::string utc_default_xml_filename = "./gps_utc_model.xml";
- const std::string iono_default_xml_filename = "./gps_iono.xml";
- const std::string ref_time_default_xml_filename = "./gps_ref_time.xml";
- const std::string ref_location_default_xml_filename = "./gps_ref_location.xml";
- eph_xml_filename_ = configuration->property("GNSS-SDR.SUPL_gps_ephemeris_xml", eph_default_xml_filename);
- //std::string utc_xml_filename = configuration_->property("GNSS-SDR.SUPL_gps_utc_model.xml", utc_default_xml_filename);
- //std::string iono_xml_filename = configuration_->property("GNSS-SDR.SUPL_gps_iono_xml", iono_default_xml_filename);
- //std::string ref_time_xml_filename = configuration_->property("GNSS-SDR.SUPL_gps_ref_time_xml", ref_time_default_xml_filename);
- //std::string ref_location_xml_filename = configuration_->property("GNSS-SDR.SUPL_gps_ref_location_xml", ref_location_default_xml_filename);
// Infer the type of receiver
/*
@@ -499,40 +487,9 @@ RtklibPvt::RtklibPvt(ConfigurationInterface* configuration,
}
-bool RtklibPvt::save_assistance_to_XML()
-{
- LOG(INFO) << "SUPL: Try to save GPS ephemeris to XML file " << eph_xml_filename_;
- std::map eph_map = pvt_->get_GPS_L1_ephemeris_map();
-
- if (eph_map.empty() == false)
- {
- std::ofstream ofs;
- try
- {
- ofs.open(eph_xml_filename_.c_str(), std::ofstream::trunc | std::ofstream::out);
- boost::archive::xml_oarchive xml(ofs);
- xml << boost::serialization::make_nvp("GNSS-SDR_ephemeris_map", eph_map);
- LOG(INFO) << "Saved GPS L1 Ephemeris map data";
- }
- catch (const std::exception& e)
- {
- LOG(WARNING) << e.what();
- return false;
- }
- }
- else
- {
- LOG(WARNING) << "Failed to save Ephemeris, map is empty";
- return false;
- }
- return true; // return variable (true == succeeded)
-}
-
-
RtklibPvt::~RtklibPvt()
{
rtkfree(&rtk);
- save_assistance_to_XML();
}
diff --git a/src/algorithms/PVT/adapters/rtklib_pvt.h b/src/algorithms/PVT/adapters/rtklib_pvt.h
index 936fd1632..c79519581 100644
--- a/src/algorithms/PVT/adapters/rtklib_pvt.h
+++ b/src/algorithms/PVT/adapters/rtklib_pvt.h
@@ -40,7 +40,7 @@
class ConfigurationInterface;
/*!
- * \brief This class implements a PvtInterface for Galileo E1
+ * \brief This class implements a PvtInterface for the RTKLIB PVT block
*/
class RtklibPvt : public PvtInterface
{
@@ -87,8 +87,6 @@ private:
std::string role_;
unsigned int in_streams_;
unsigned int out_streams_;
- std::string eph_xml_filename_;
- bool save_assistance_to_XML();
};
#endif
diff --git a/src/algorithms/PVT/gnuradio_blocks/rtklib_pvt_cc.cc b/src/algorithms/PVT/gnuradio_blocks/rtklib_pvt_cc.cc
index 2f9bb177d..d7de9453c 100644
--- a/src/algorithms/PVT/gnuradio_blocks/rtklib_pvt_cc.cc
+++ b/src/algorithms/PVT/gnuradio_blocks/rtklib_pvt_cc.cc
@@ -396,8 +396,7 @@ rtklib_pvt_cc::~rtklib_pvt_cc()
msgctl(sysv_msqid, IPC_RMID, NULL);
// save GPS L2CM ephemeris to XML file
- std::string file_name = "eph_GPS_CNAV.xml";
-
+ std::string file_name = "gps_cnav_ephemeris.xml";
if (d_ls_pvt->gps_cnav_ephemeris_map.empty() == false)
{
std::ofstream ofs;
@@ -405,7 +404,7 @@ rtklib_pvt_cc::~rtklib_pvt_cc()
{
ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
boost::archive::xml_oarchive xml(ofs);
- xml << boost::serialization::make_nvp("GNSS-SDR_ephemeris_map", d_ls_pvt->gps_cnav_ephemeris_map);
+ xml << boost::serialization::make_nvp("GNSS-SDR_cnav_ephemeris_map", d_ls_pvt->gps_cnav_ephemeris_map);
LOG(INFO) << "Saved GPS L2CM or L5 Ephemeris map data";
}
catch (std::exception& e)
@@ -415,12 +414,11 @@ rtklib_pvt_cc::~rtklib_pvt_cc()
}
else
{
- LOG(WARNING) << "Failed to save GPS L2CM or L5 Ephemeris, map is empty";
+ LOG(INFO) << "Failed to save GPS L2CM or L5 Ephemeris, map is empty";
}
// save GPS L1 CA ephemeris to XML file
- file_name = "eph_GPS_L1CA.xml";
-
+ file_name = "gps_ephemeris.xml";
if (d_ls_pvt->gps_ephemeris_map.empty() == false)
{
std::ofstream ofs;
@@ -438,12 +436,11 @@ rtklib_pvt_cc::~rtklib_pvt_cc()
}
else
{
- LOG(WARNING) << "Failed to save GPS L1 CA Ephemeris, map is empty";
+ LOG(INFO) << "Failed to save GPS L1 CA Ephemeris, map is empty";
}
// save Galileo E1 ephemeris to XML file
- file_name = "eph_Galileo_E1.xml";
-
+ file_name = "gal_ephemeris.xml";
if (d_ls_pvt->galileo_ephemeris_map.empty() == false)
{
std::ofstream ofs;
@@ -451,7 +448,7 @@ rtklib_pvt_cc::~rtklib_pvt_cc()
{
ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
boost::archive::xml_oarchive xml(ofs);
- xml << boost::serialization::make_nvp("GNSS-SDR_ephemeris_map", d_ls_pvt->galileo_ephemeris_map);
+ xml << boost::serialization::make_nvp("GNSS-SDR_gal_ephemeris_map", d_ls_pvt->galileo_ephemeris_map);
LOG(INFO) << "Saved Galileo E1 Ephemeris map data";
}
catch (const std::exception& e)
@@ -461,12 +458,11 @@ rtklib_pvt_cc::~rtklib_pvt_cc()
}
else
{
- LOG(WARNING) << "Failed to save Galileo E1 Ephemeris, map is empty";
+ LOG(INFO) << "Failed to save Galileo E1 Ephemeris, map is empty";
}
// save GLONASS GNAV ephemeris to XML file
file_name = "eph_GLONASS_GNAV.xml";
-
if (d_ls_pvt->glonass_gnav_ephemeris_map.empty() == false)
{
std::ofstream ofs;
@@ -474,7 +470,7 @@ rtklib_pvt_cc::~rtklib_pvt_cc()
{
ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
boost::archive::xml_oarchive xml(ofs);
- xml << boost::serialization::make_nvp("GNSS-SDR_ephemeris_map", d_ls_pvt->glonass_gnav_ephemeris_map);
+ xml << boost::serialization::make_nvp("GNSS-SDR_gnav_ephemeris_map", d_ls_pvt->glonass_gnav_ephemeris_map);
LOG(INFO) << "Saved GLONASS GNAV Ephemeris map data";
}
catch (std::exception& e)
@@ -484,7 +480,117 @@ rtklib_pvt_cc::~rtklib_pvt_cc()
}
else
{
- LOG(WARNING) << "Failed to save GLONASS GNAV Ephemeris, map is empty";
+ LOG(INFO) << "Failed to save GLONASS GNAV Ephemeris, map is empty";
+ }
+
+ // Save GPS UTC model parameters
+ file_name = "gps_utc_model.xml";
+ if (d_ls_pvt->gps_utc_model.valid)
+ {
+ std::ofstream ofs;
+ try
+ {
+ ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
+ boost::archive::xml_oarchive xml(ofs);
+ xml << boost::serialization::make_nvp("GNSS-SDR_utc_model", d_ls_pvt->gps_utc_model);
+ LOG(INFO) << "Saved GPS UTC model parameters";
+ }
+ catch (std::exception& e)
+ {
+ LOG(WARNING) << e.what();
+ }
+ }
+ else
+ {
+ LOG(INFO) << "Failed to save GPS UTC model parameters, not valid data";
+ }
+
+ // Save Galileo UTC model parameters
+ file_name = "gal_utc_model.xml";
+ if (d_ls_pvt->galileo_utc_model.A0_6 != 0.0)
+ {
+ std::ofstream ofs;
+ try
+ {
+ ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
+ boost::archive::xml_oarchive xml(ofs);
+ xml << boost::serialization::make_nvp("GNSS-SDR_gal_utc_model", d_ls_pvt->galileo_utc_model);
+ LOG(INFO) << "Saved Galileo UTC model parameters";
+ }
+ catch (std::exception& e)
+ {
+ LOG(WARNING) << e.what();
+ }
+ }
+ else
+ {
+ LOG(INFO) << "Failed to save Galileo UTC model parameters, not valid data";
+ }
+
+ // Save GPS CNAV UTC model parameters
+ file_name = "gps_cnav_utc_model.xml";
+ if (d_ls_pvt->gps_cnav_utc_model.valid)
+ {
+ std::ofstream ofs;
+ try
+ {
+ ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
+ boost::archive::xml_oarchive xml(ofs);
+ xml << boost::serialization::make_nvp("GNSS-SDR_cnav_utc_model", d_ls_pvt->gps_cnav_utc_model);
+ LOG(INFO) << "Saved GPS CNAV UTC model parameters";
+ }
+ catch (std::exception& e)
+ {
+ LOG(WARNING) << e.what();
+ }
+ }
+ else
+ {
+ LOG(INFO) << "Failed to save GPS CNAV UTC model parameters, not valid data";
+ }
+
+ // save GLONASS GNAV ephemeris to XML file
+ file_name = "glo_gnav_ephemeris.xml";
+ if (d_ls_pvt->glonass_gnav_ephemeris_map.empty() == false)
+ {
+ std::ofstream ofs;
+ try
+ {
+ ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
+ boost::archive::xml_oarchive xml(ofs);
+ xml << boost::serialization::make_nvp("GNSS-SDR_gnav_ephemeris_map", d_ls_pvt->glonass_gnav_ephemeris_map);
+ LOG(INFO) << "Saved GLONASS GNAV ephemeris map data";
+ }
+ catch (std::exception& e)
+ {
+ LOG(WARNING) << e.what();
+ }
+ }
+ else
+ {
+ LOG(INFO) << "Failed to save GLONASS GNAV ephemeris, map is empty";
+ }
+
+ // save GLONASS UTC model parameters to XML file
+ file_name = "glo_utc_model.xml";
+ if (d_ls_pvt->glonass_gnav_utc_model.valid)
+ {
+ std::ofstream ofs;
+ try
+ {
+ ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
+ boost::archive::xml_oarchive xml(ofs);
+ xml << boost::serialization::make_nvp("GNSS-SDR_gnav_utc_model", d_ls_pvt->glonass_gnav_utc_model);
+ LOG(INFO) << "Saved GLONASS UTC model parameters";
+ }
+ catch (std::exception& e)
+ {
+ LOG(WARNING) << e.what();
+ }
+ }
+ else
+ {
+ LOG(INFO) << "Failed to save GLONASS GNAV ephemeris, not valid data";
}
}
diff --git a/src/algorithms/libs/volk_gnsssdr_module/volk_gnsssdr/cmake/cmake_uninstall.cmake.in b/src/algorithms/libs/volk_gnsssdr_module/volk_gnsssdr/cmake/cmake_uninstall.cmake.in
index a6191a104..d026a667a 100644
--- a/src/algorithms/libs/volk_gnsssdr_module/volk_gnsssdr/cmake/cmake_uninstall.cmake.in
+++ b/src/algorithms/libs/volk_gnsssdr_module/volk_gnsssdr/cmake/cmake_uninstall.cmake.in
@@ -25,10 +25,10 @@ string(REGEX REPLACE "\n" ";" files "${files}")
foreach(file ${files})
message(STATUS "Uninstalling $ENV{DESTDIR}${file}")
if(IS_SYMLINK "$ENV{DESTDIR}${file}" OR EXISTS "$ENV{DESTDIR}${file}")
- exec_program(
- "@CMAKE_COMMAND@" ARGS "-E remove \"$ENV{DESTDIR}${file}\""
+ execute_process(
+ COMMAND @CMAKE_COMMAND@ -E remove \"$ENV{DESTDIR}${file}\"
OUTPUT_VARIABLE rm_out
- RETURN_VALUE rm_retval
+ RESULT_VARIABLE rm_retval
)
if(NOT "${rm_retval}" STREQUAL 0)
message(FATAL_ERROR "Problem when removing $ENV{DESTDIR}${file}")
diff --git a/src/core/libs/gnss_sdr_supl_client.cc b/src/core/libs/gnss_sdr_supl_client.cc
index b571baefe..022f658fe 100644
--- a/src/core/libs/gnss_sdr_supl_client.cc
+++ b/src/core/libs/gnss_sdr_supl_client.cc
@@ -388,46 +388,6 @@ bool gnss_sdr_supl_client::load_ephemeris_xml(const std::string file_name)
}
-bool gnss_sdr_supl_client::load_gal_ephemeris_xml(const std::string file_name)
-{
- std::ifstream ifs;
- try
- {
- ifs.open(file_name.c_str(), std::ifstream::binary | std::ifstream::in);
- boost::archive::xml_iarchive xml(ifs);
- gal_ephemeris_map.clear();
- xml >> boost::serialization::make_nvp("GNSS-SDR_ephemeris_map", this->gal_ephemeris_map);
- LOG(INFO) << "Loaded Ephemeris map data with " << this->gal_ephemeris_map.size() << " satellites";
- }
- catch (std::exception& e)
- {
- LOG(WARNING) << e.what() << "File: " << file_name;
- return false;
- }
- return true;
-}
-
-
-bool gnss_sdr_supl_client::load_cnav_ephemeris_xml(const std::string file_name)
-{
- std::ifstream ifs;
- try
- {
- ifs.open(file_name.c_str(), std::ifstream::binary | std::ifstream::in);
- boost::archive::xml_iarchive xml(ifs);
- gps_cnav_ephemeris_map.clear();
- xml >> boost::serialization::make_nvp("GNSS-SDR_ephemeris_map", this->gps_cnav_ephemeris_map);
- LOG(INFO) << "Loaded Ephemeris map data with " << this->gps_cnav_ephemeris_map.size() << " satellites";
- }
- catch (std::exception& e)
- {
- LOG(WARNING) << e.what() << "File: " << file_name;
- return false;
- }
- return true;
-}
-
-
bool gnss_sdr_supl_client::save_ephemeris_map_xml(const std::string file_name, std::map eph_map)
{
if (eph_map.empty() == false)
@@ -455,6 +415,147 @@ bool gnss_sdr_supl_client::save_ephemeris_map_xml(const std::string file_name, s
}
+bool gnss_sdr_supl_client::load_gal_ephemeris_xml(const std::string file_name)
+{
+ std::ifstream ifs;
+ try
+ {
+ ifs.open(file_name.c_str(), std::ifstream::binary | std::ifstream::in);
+ boost::archive::xml_iarchive xml(ifs);
+ gal_ephemeris_map.clear();
+ xml >> boost::serialization::make_nvp("GNSS-SDR_gal_ephemeris_map", this->gal_ephemeris_map);
+ LOG(INFO) << "Loaded Ephemeris map data with " << this->gal_ephemeris_map.size() << " satellites";
+ }
+ catch (std::exception& e)
+ {
+ LOG(WARNING) << e.what() << "File: " << file_name;
+ return false;
+ }
+ return true;
+}
+
+
+bool save_gal_ephemeris_map_xml(const std::string file_name, std::map eph_map)
+{
+ if (eph_map.empty() == false)
+ {
+ std::ofstream ofs;
+ try
+ {
+ ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
+ boost::archive::xml_oarchive xml(ofs);
+ xml << boost::serialization::make_nvp("GNSS-SDR_gal_ephemeris_map", eph_map);
+ LOG(INFO) << "Saved Galileo ephemeris map data";
+ }
+ catch (std::exception& e)
+ {
+ LOG(WARNING) << e.what();
+ return false;
+ }
+ }
+ else
+ {
+ LOG(WARNING) << "Failed to save Galileo ephemeris, map is empty";
+ return false;
+ }
+ return true;
+}
+
+
+bool gnss_sdr_supl_client::load_cnav_ephemeris_xml(const std::string file_name)
+{
+ std::ifstream ifs;
+ try
+ {
+ ifs.open(file_name.c_str(), std::ifstream::binary | std::ifstream::in);
+ boost::archive::xml_iarchive xml(ifs);
+ gps_cnav_ephemeris_map.clear();
+ xml >> boost::serialization::make_nvp("GNSS-SDR_cnav_ephemeris_map", this->gps_cnav_ephemeris_map);
+ LOG(INFO) << "Loaded Ephemeris map data with " << this->gps_cnav_ephemeris_map.size() << " satellites";
+ }
+ catch (std::exception& e)
+ {
+ LOG(WARNING) << e.what() << "File: " << file_name;
+ return false;
+ }
+ return true;
+}
+
+
+bool save_cnav_ephemeris_map_xml(const std::string file_name, std::map eph_map)
+{
+ if (eph_map.empty() == false)
+ {
+ std::ofstream ofs;
+ try
+ {
+ ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
+ boost::archive::xml_oarchive xml(ofs);
+ xml << boost::serialization::make_nvp("GNSS-SDR_cnav_ephemeris_map", eph_map);
+ LOG(INFO) << "Saved GPS CNAV ephemeris map data";
+ }
+ catch (std::exception& e)
+ {
+ LOG(WARNING) << e.what();
+ return false;
+ }
+ }
+ else
+ {
+ LOG(WARNING) << "Failed to save GPS CNAV ephemeris, map is empty";
+ return false;
+ }
+ return true;
+}
+
+
+bool gnss_sdr_supl_client::load_gnav_ephemeris_xml(const std::string file_name)
+{
+ std::ifstream ifs;
+ try
+ {
+ ifs.open(file_name.c_str(), std::ifstream::binary | std::ifstream::in);
+ boost::archive::xml_iarchive xml(ifs);
+ gps_cnav_ephemeris_map.clear();
+ xml >> boost::serialization::make_nvp("GNSS-SDR_gnav_ephemeris_map", this->glonass_gnav_ephemeris_map);
+ LOG(INFO) << "Loaded GLONASS ephemeris map data with " << this->gps_cnav_ephemeris_map.size() << " satellites";
+ }
+ catch (std::exception& e)
+ {
+ LOG(WARNING) << e.what() << "File: " << file_name;
+ return false;
+ }
+ return true;
+}
+
+
+bool save_gnav_ephemeris_map_xml(const std::string file_name, std::map eph_map)
+{
+ if (eph_map.empty() == false)
+ {
+ std::ofstream ofs;
+ try
+ {
+ ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
+ boost::archive::xml_oarchive xml(ofs);
+ xml << boost::serialization::make_nvp("GNSS-SDR_gnav_ephemeris_map", eph_map);
+ LOG(INFO) << "Saved GLONASS GNAV ephemeris map data";
+ }
+ catch (std::exception& e)
+ {
+ LOG(WARNING) << e.what();
+ return false;
+ }
+ }
+ else
+ {
+ LOG(WARNING) << "Failed to save GLONASS GNAV ephemeris, map is empty";
+ return false;
+ }
+ return true;
+}
+
+
bool gnss_sdr_supl_client::load_utc_xml(const std::string file_name)
{
std::ifstream ifs;
@@ -462,7 +563,7 @@ bool gnss_sdr_supl_client::load_utc_xml(const std::string file_name)
{
ifs.open(file_name.c_str(), std::ifstream::binary | std::ifstream::in);
boost::archive::xml_iarchive xml(ifs);
- xml >> boost::serialization::make_nvp("GNSS-SDR_utc_map", this->gps_utc);
+ xml >> boost::serialization::make_nvp("GNSS-SDR_utc_model", this->gps_utc);
LOG(INFO) << "Loaded UTC model data";
}
catch (std::exception& e)
@@ -474,6 +575,79 @@ bool gnss_sdr_supl_client::load_utc_xml(const std::string file_name)
}
+bool gnss_sdr_supl_client::save_utc_xml(const std::string file_name, Gps_Utc_Model& utc)
+{
+ if (utc.valid)
+ {
+ std::ofstream ofs;
+ try
+ {
+ ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
+ boost::archive::xml_oarchive xml(ofs);
+ xml << boost::serialization::make_nvp("GNSS-SDR_utc_model", utc);
+ LOG(INFO) << "Saved GPS UTC Model data";
+ }
+ catch (std::exception& e)
+ {
+ LOG(WARNING) << e.what();
+ return false;
+ }
+ }
+ else
+ {
+ LOG(WARNING) << "Failed to save GPS UTC model, no valid data";
+ return false;
+ }
+ return true;
+}
+
+
+bool gnss_sdr_supl_client::load_cnav_utc_xml(const std::string file_name)
+{
+ std::ifstream ifs;
+ try
+ {
+ ifs.open(file_name.c_str(), std::ifstream::binary | std::ifstream::in);
+ boost::archive::xml_iarchive xml(ifs);
+ xml >> boost::serialization::make_nvp("GNSS-SDR_cnav_utc_model", this->gps_cnav_utc);
+ LOG(INFO) << "Loaded CNAV UTC model data";
+ }
+ catch (std::exception& e)
+ {
+ LOG(WARNING) << e.what() << "File: " << file_name;
+ return false;
+ }
+ return true;
+}
+
+
+bool gnss_sdr_supl_client::save_cnav_utc_xml(const std::string file_name, Gps_CNAV_Utc_Model& utc)
+{
+ if (utc.valid)
+ {
+ std::ofstream ofs;
+ try
+ {
+ ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
+ boost::archive::xml_oarchive xml(ofs);
+ xml << boost::serialization::make_nvp("GNSS-SDR_cnav_utc_model", utc);
+ LOG(INFO) << "Saved GPS CNAV UTC model data";
+ }
+ catch (std::exception& e)
+ {
+ LOG(WARNING) << e.what();
+ return false;
+ }
+ }
+ else
+ {
+ LOG(WARNING) << "Failed to save GPS CNAV UTC model, no valid data";
+ return false;
+ }
+ return true;
+}
+
+
bool gnss_sdr_supl_client::load_gal_utc_xml(const std::string file_name)
{
std::ifstream ifs;
@@ -481,7 +655,7 @@ bool gnss_sdr_supl_client::load_gal_utc_xml(const std::string file_name)
{
ifs.open(file_name.c_str(), std::ifstream::binary | std::ifstream::in);
boost::archive::xml_iarchive xml(ifs);
- xml >> boost::serialization::make_nvp("GNSS-SDR_gal_utc_map", this->gal_utc);
+ xml >> boost::serialization::make_nvp("GNSS-SDR_gal_utc_model", this->gal_utc);
LOG(INFO) << "Loaded Galileo UTC model data";
}
catch (std::exception& e)
@@ -493,17 +667,17 @@ bool gnss_sdr_supl_client::load_gal_utc_xml(const std::string file_name)
}
-bool gnss_sdr_supl_client::save_utc_map_xml(const std::string file_name, std::map utc_map)
+bool gnss_sdr_supl_client::save_gal_utc_xml(const std::string file_name, Galileo_Utc_Model& utc)
{
- if (utc_map.empty() == false)
+ if (utc.flag_utc_model)
{
std::ofstream ofs;
try
{
ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
boost::archive::xml_oarchive xml(ofs);
- xml << boost::serialization::make_nvp("GNSS-SDR_utc_map", utc_map);
- LOG(INFO) << "Saved UTC Model data";
+ xml << boost::serialization::make_nvp("GNSS-SDR_gal_utc_model", utc);
+ LOG(INFO) << "Saved Galileo UTC Model data";
}
catch (std::exception& e)
{
@@ -513,7 +687,7 @@ bool gnss_sdr_supl_client::save_utc_map_xml(const std::string file_name, std::ma
}
else
{
- LOG(WARNING) << "Failed to save UTC model, map is empty";
+ LOG(WARNING) << "Failed to save Galileo UTC model, no valid data";
return false;
}
return true;
@@ -527,7 +701,7 @@ bool gnss_sdr_supl_client::load_iono_xml(const std::string file_name)
{
ifs.open(file_name.c_str(), std::ifstream::binary | std::ifstream::in);
boost::archive::xml_iarchive xml(ifs);
- xml >> boost::serialization::make_nvp("GNSS-SDR_iono_map", this->gps_iono);
+ xml >> boost::serialization::make_nvp("GNSS-SDR_iono_model", this->gps_iono);
LOG(INFO) << "Loaded IONO model data";
}
catch (std::exception& e)
@@ -539,6 +713,33 @@ bool gnss_sdr_supl_client::load_iono_xml(const std::string file_name)
}
+bool gnss_sdr_supl_client::save_iono_xml(const std::string file_name, Gps_Iono& iono)
+{
+ if (iono.valid)
+ {
+ std::ofstream ofs;
+ try
+ {
+ ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
+ boost::archive::xml_oarchive xml(ofs);
+ xml << boost::serialization::make_nvp("GNSS-SDR_iono_model", iono);
+ LOG(INFO) << "Saved IONO Model data";
+ }
+ catch (std::exception& e)
+ {
+ LOG(WARNING) << e.what();
+ return false;
+ }
+ }
+ else
+ {
+ LOG(WARNING) << "Failed to save IONO model, map is empty";
+ return false;
+ }
+ return true;
+}
+
+
bool gnss_sdr_supl_client::load_gal_iono_xml(const std::string file_name)
{
std::ifstream ifs;
@@ -546,7 +747,7 @@ bool gnss_sdr_supl_client::load_gal_iono_xml(const std::string file_name)
{
ifs.open(file_name.c_str(), std::ifstream::binary | std::ifstream::in);
boost::archive::xml_iarchive xml(ifs);
- xml >> boost::serialization::make_nvp("GNSS-SDR_iono_gal_map", this->gal_iono);
+ xml >> boost::serialization::make_nvp("GNSS-SDR_gal_iono_model", this->gal_iono);
LOG(INFO) << "Loaded Galileo IONO model data";
}
catch (std::exception& e)
@@ -558,17 +759,17 @@ bool gnss_sdr_supl_client::load_gal_iono_xml(const std::string file_name)
}
-bool gnss_sdr_supl_client::save_iono_map_xml(const std::string file_name, std::map iono_map)
+bool gnss_sdr_supl_client::save_gal_iono_xml(const std::string file_name, Galileo_Iono& iono)
{
- if (iono_map.empty() == false)
+ if (iono.ai0_5 != 0.0)
{
std::ofstream ofs;
try
{
ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
boost::archive::xml_oarchive xml(ofs);
- xml << boost::serialization::make_nvp("GNSS-SDR_iono_map", iono_map);
- LOG(INFO) << "Saved IONO Model data";
+ xml << boost::serialization::make_nvp("GNSS-SDR_gal_iono_model", iono);
+ LOG(INFO) << "Saved Galileo IONO Model data";
}
catch (std::exception& e)
{
@@ -578,7 +779,53 @@ bool gnss_sdr_supl_client::save_iono_map_xml(const std::string file_name, std::m
}
else
{
- LOG(WARNING) << "Failed to save IONO model, map is empty";
+ LOG(WARNING) << "Failed to save Galileo IONO model, map is empty";
+ return false;
+ }
+ return true;
+}
+
+
+bool gnss_sdr_supl_client::load_glo_utc_xml(const std::string file_name)
+{
+ std::ifstream ifs;
+ try
+ {
+ ifs.open(file_name.c_str(), std::ifstream::binary | std::ifstream::in);
+ boost::archive::xml_iarchive xml(ifs);
+ xml >> boost::serialization::make_nvp("GNSS-SDR_glo_utc_model", this->glo_gnav_utc);
+ LOG(INFO) << "Loaded UTC model data";
+ }
+ catch (std::exception& e)
+ {
+ LOG(WARNING) << e.what() << "File: " << file_name;
+ return false;
+ }
+ return true;
+}
+
+
+bool gnss_sdr_supl_client::save_glo_utc_xml(const std::string file_name, Glonass_Gnav_Utc_Model& utc)
+{
+ if (utc.valid)
+ {
+ std::ofstream ofs;
+ try
+ {
+ ofs.open(file_name.c_str(), std::ofstream::trunc | std::ofstream::out);
+ boost::archive::xml_oarchive xml(ofs);
+ xml << boost::serialization::make_nvp("GNSS-SDR_glo_utc_model", utc);
+ LOG(INFO) << "Saved Glonass UTC Model data";
+ }
+ catch (std::exception& e)
+ {
+ LOG(WARNING) << e.what();
+ return false;
+ }
+ }
+ else
+ {
+ LOG(WARNING) << "Failed to save Glonass UTC model, no valid data";
return false;
}
return true;
diff --git a/src/core/receiver/control_thread.cc b/src/core/receiver/control_thread.cc
index de3dc893b..dbc433241 100644
--- a/src/core/receiver/control_thread.cc
+++ b/src/core/receiver/control_thread.cc
@@ -47,6 +47,8 @@
#include "gps_iono.h"
#include "gps_utc_model.h"
#include "gps_almanac.h"
+#include "glonass_gnav_ephemeris.h"
+#include "glonass_gnav_utc_model.h"
#include
#include
#include
@@ -207,91 +209,148 @@ bool ControlThread::read_assistance_from_XML()
std::string eph_gal_xml_filename = configuration_->property("GNSS-SDR.SUPL_gal_ephemeris_xml", eph_gal_default_xml_filename);
std::string eph_cnav_xml_filename = configuration_->property("GNSS-SDR.SUPL_gps_cnav_ephemeris_xml", eph_cnav_default_xml_filename);
std::string gal_utc_xml_filename = configuration_->property("GNSS-SDR.SUPL_gal_utc_model.xml", gal_utc_default_xml_filename);
+ std::string cnav_utc_xml_filename = configuration_->property("GNSS-SDR.SUPL_cnav_utc_model.xml", cnav_utc_default_xml_filename);
+ std::string eph_glo_xml_filename = configuration_->property("GNSS-SDR.SUPL_glo_ephemeris_xml", eph_glo_gnav_default_xml_filename);
+ std::string glo_utc_xml_filename = configuration_->property("GNSS-SDR.SUPL_glo_utc_model.xml", glo_utc_default_xml_filename);
- std::cout << "Trying to read GNSS ephemeris from XML file(s): "
- << ((eph_xml_filename.compare(eph_default_xml_filename) != 0) ? eph_xml_filename + " " : "")
- << ((eph_gal_xml_filename.compare(eph_gal_default_xml_filename) != 0) ? eph_gal_xml_filename + " " : "")
- << ((eph_cnav_xml_filename.compare(eph_cnav_default_xml_filename) != 0) ? eph_gal_xml_filename : "")
- << std::endl;
-
- if (supl_client_ephemeris_.load_ephemeris_xml(eph_xml_filename) == true)
+ if (configuration_->property("GNSS-SDR.AGNSS_XML_enabled", false) == true)
{
- std::map::const_iterator gps_eph_iter;
- for (gps_eph_iter = supl_client_ephemeris_.gps_ephemeris_map.cbegin();
- gps_eph_iter != supl_client_ephemeris_.gps_ephemeris_map.cend();
- gps_eph_iter++)
+ eph_xml_filename = configuration_->property("GNSS-SDR.AGNSS_gps_ephemeris_xml", eph_default_xml_filename);
+ utc_xml_filename = configuration_->property("GNSS-SDR.AGNSS_gps_utc_model.xml", utc_default_xml_filename);
+ iono_xml_filename = configuration_->property("GNSS-SDR.AGNSS_gps_iono_xml", iono_default_xml_filename);
+ gal_iono_xml_filename = configuration_->property("GNSS-SDR.AGNSS_gal_iono_xml", gal_iono_default_xml_filename);
+ ref_time_xml_filename = configuration_->property("GNSS-SDR.AGNSS_gps_ref_time_xml", ref_time_default_xml_filename);
+ ref_location_xml_filename = configuration_->property("GNSS-SDR.AGNSS_gps_ref_location_xml", ref_location_default_xml_filename);
+ eph_gal_xml_filename = configuration_->property("GNSS-SDR.AGNSS_gal_ephemeris_xml", eph_gal_default_xml_filename);
+ eph_cnav_xml_filename = configuration_->property("GNSS-SDR.AGNSS_gps_cnav_ephemeris_xml", eph_cnav_default_xml_filename);
+ gal_utc_xml_filename = configuration_->property("GNSS-SDR.AGNSS_gal_utc_model.xml", gal_utc_default_xml_filename);
+ cnav_utc_xml_filename = configuration_->property("GNSS-SDR.AGNSS_cnav_utc_model.xml", cnav_utc_default_xml_filename);
+ eph_glo_xml_filename = configuration_->property("GNSS-SDR.AGNSS_glo_ephemeris_xml", eph_glo_gnav_default_xml_filename);
+ glo_utc_xml_filename = configuration_->property("GNSS-SDR.AGNSS_glo_utc_model.xml", glo_utc_default_xml_filename);
+ }
+
+ std::cout << "Trying to read GNSS ephemeris from XML file(s)..." << std::endl;
+
+ if (configuration_->property("Channels_1C.count", 0) > 0)
+ {
+ if (supl_client_ephemeris_.load_ephemeris_xml(eph_xml_filename) == true)
{
- std::cout << "From XML file: Read NAV ephemeris for satellite " << Gnss_Satellite("GPS", gps_eph_iter->second.i_satellite_PRN) << std::endl;
- std::shared_ptr tmp_obj = std::make_shared(gps_eph_iter->second);
- flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
+ std::map::const_iterator gps_eph_iter;
+ for (gps_eph_iter = supl_client_ephemeris_.gps_ephemeris_map.cbegin();
+ gps_eph_iter != supl_client_ephemeris_.gps_ephemeris_map.cend();
+ gps_eph_iter++)
+ {
+ std::cout << "From XML file: Read NAV ephemeris for satellite " << Gnss_Satellite("GPS", gps_eph_iter->second.i_satellite_PRN) << std::endl;
+ std::shared_ptr tmp_obj = std::make_shared(gps_eph_iter->second);
+ flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
+ }
+ ret = true;
}
- ret = true;
- }
- if (supl_client_ephemeris_.load_gal_ephemeris_xml(eph_gal_xml_filename) == true)
- {
- std::map::const_iterator gal_eph_iter;
- for (gal_eph_iter = supl_client_ephemeris_.gal_ephemeris_map.cbegin();
- gal_eph_iter != supl_client_ephemeris_.gal_ephemeris_map.cend();
- gal_eph_iter++)
+ if (supl_client_acquisition_.load_utc_xml(utc_xml_filename) == true)
{
- std::cout << "From XML file: Read ephemeris for satellite " << Gnss_Satellite("Galileo", gal_eph_iter->second.i_satellite_PRN) << std::endl;
- std::shared_ptr tmp_obj = std::make_shared(gal_eph_iter->second);
+ std::shared_ptr tmp_obj = std::make_shared(supl_client_acquisition_.gps_utc);
flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
+ std::cout << "From XML file: Read GPS UTC model parameters." << std::endl;
+ ret = true;
}
- ret = true;
- }
- if (supl_client_ephemeris_.load_cnav_ephemeris_xml(eph_cnav_xml_filename) == true)
- {
- std::map::const_iterator gps_cnav_eph_iter;
- for (gps_cnav_eph_iter = supl_client_ephemeris_.gps_cnav_ephemeris_map.cbegin();
- gps_cnav_eph_iter != supl_client_ephemeris_.gps_cnav_ephemeris_map.cend();
- gps_cnav_eph_iter++)
+ if (supl_client_acquisition_.load_iono_xml(iono_xml_filename) == true)
{
- std::cout << "From XML file: Read CNAV ephemeris for satellite " << Gnss_Satellite("GPS", gps_cnav_eph_iter->second.i_satellite_PRN) << std::endl;
- std::shared_ptr tmp_obj = std::make_shared(gps_cnav_eph_iter->second);
+ std::shared_ptr tmp_obj = std::make_shared(supl_client_acquisition_.gps_iono);
flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
+ std::cout << "From XML file: Read GPS ionosphere model parameters." << std::endl;
+ ret = true;
}
- ret = true;
}
- if (supl_client_acquisition_.load_utc_xml(utc_xml_filename) == true)
+ if ((configuration_->property("Channels_1B.count", 0) > 0) or (configuration_->property("Channels_5X.count", 0) > 0))
{
- std::shared_ptr tmp_obj = std::make_shared(supl_client_acquisition_.gps_utc);
- flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
- std::cout << "From XML file: Read GPS UTC parameters." << std::endl;
- ret = true;
+ if (supl_client_ephemeris_.load_gal_ephemeris_xml(eph_gal_xml_filename) == true)
+ {
+ std::map::const_iterator gal_eph_iter;
+ for (gal_eph_iter = supl_client_ephemeris_.gal_ephemeris_map.cbegin();
+ gal_eph_iter != supl_client_ephemeris_.gal_ephemeris_map.cend();
+ gal_eph_iter++)
+ {
+ std::cout << "From XML file: Read ephemeris for satellite " << Gnss_Satellite("Galileo", gal_eph_iter->second.i_satellite_PRN) << std::endl;
+ std::shared_ptr tmp_obj = std::make_shared(gal_eph_iter->second);
+ flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
+ }
+ ret = true;
+ }
+
+ if (supl_client_acquisition_.load_gal_iono_xml(gal_iono_xml_filename) == true)
+ {
+ std::shared_ptr tmp_obj = std::make_shared(supl_client_acquisition_.gal_iono);
+ flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
+ std::cout << "From XML file: Read Galileo ionosphere model parameters." << std::endl;
+ ret = true;
+ }
+
+ if (supl_client_acquisition_.load_gal_utc_xml(gal_utc_xml_filename) == true)
+ {
+ std::shared_ptr tmp_obj = std::make_shared(supl_client_acquisition_.gal_utc);
+ flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
+ std::cout << "From XML file: Read Galileo UTC model parameters." << std::endl;
+ ret = true;
+ }
}
- if (supl_client_acquisition_.load_iono_xml(iono_xml_filename) == true)
+ if ((configuration_->property("Channels_2S.count", 0) > 0) or (configuration_->property("Channels_L5.count", 0) > 0))
{
- std::shared_ptr tmp_obj = std::make_shared(supl_client_acquisition_.gps_iono);
- flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
- std::cout << "From XML file: Read GPS iono parameters." << std::endl;
- ret = true;
+ if (supl_client_ephemeris_.load_cnav_ephemeris_xml(eph_cnav_xml_filename) == true)
+ {
+ std::map::const_iterator gps_cnav_eph_iter;
+ for (gps_cnav_eph_iter = supl_client_ephemeris_.gps_cnav_ephemeris_map.cbegin();
+ gps_cnav_eph_iter != supl_client_ephemeris_.gps_cnav_ephemeris_map.cend();
+ gps_cnav_eph_iter++)
+ {
+ std::cout << "From XML file: Read CNAV ephemeris for satellite " << Gnss_Satellite("GPS", gps_cnav_eph_iter->second.i_satellite_PRN) << std::endl;
+ std::shared_ptr tmp_obj = std::make_shared(gps_cnav_eph_iter->second);
+ flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
+ }
+ ret = true;
+ }
+
+ if (supl_client_acquisition_.load_cnav_utc_xml(cnav_utc_xml_filename) == true)
+ {
+ std::shared_ptr tmp_obj = std::make_shared(supl_client_acquisition_.gps_cnav_utc);
+ flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
+ std::cout << "From XML file: Read GPS CNAV UTC model parameters." << std::endl;
+ ret = true;
+ }
}
- if (supl_client_acquisition_.load_gal_iono_xml(gal_iono_xml_filename) == true)
+ if ((configuration_->property("Channels_1G.count", 0) > 0) or (configuration_->property("Channels_2G.count", 0) > 0))
{
- std::shared_ptr tmp_obj = std::make_shared(supl_client_acquisition_.gal_iono);
- flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
- std::cout << "From XML file: Read Galileo iono parameters." << std::endl;
- ret = true;
- }
+ if (supl_client_ephemeris_.load_gnav_ephemeris_xml(eph_glo_xml_filename) == true)
+ {
+ std::map::const_iterator glo_gnav_eph_iter;
+ for (glo_gnav_eph_iter = supl_client_ephemeris_.glonass_gnav_ephemeris_map.cbegin();
+ glo_gnav_eph_iter != supl_client_ephemeris_.glonass_gnav_ephemeris_map.cend();
+ glo_gnav_eph_iter++)
+ {
+ std::cout << "From XML file: Read GLONASS GNAV ephemeris for satellite " << Gnss_Satellite("GLONASS", glo_gnav_eph_iter->second.i_satellite_PRN) << std::endl;
+ std::shared_ptr tmp_obj = std::make_shared(glo_gnav_eph_iter->second);
+ flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
+ }
+ ret = true;
+ }
- if (supl_client_acquisition_.load_gal_utc_xml(gal_utc_xml_filename) == true)
- {
- std::shared_ptr tmp_obj = std::make_shared(supl_client_acquisition_.gal_utc);
- flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
- std::cout << "From XML file: Read Galileo UTC parameters." << std::endl;
- ret = true;
+ if (supl_client_acquisition_.load_glo_utc_xml(glo_utc_xml_filename) == true)
+ {
+ std::shared_ptr tmp_obj = std::make_shared(supl_client_acquisition_.glo_gnav_utc);
+ flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
+ std::cout << "From XML file: Read GLONASS UTC model parameters." << std::endl;
+ ret = true;
+ }
}
if (ret == false)
{
- std::cout << "ERROR: SUPL client error reading XML" << std::endl;
- std::cout << "Disabling SUPL assistance..." << std::endl;
+ std::cout << "Error reading XML files" << std::endl;
+ std::cout << "Disabling GNSS assistance..." << std::endl;
}
// Only look for {ref time, ref location} if SUPL is enabled
@@ -307,7 +366,7 @@ bool ControlThread::read_assistance_from_XML()
}
else
{
- LOG(INFO) << "SUPL: couldn't read Ref Time XML";
+ LOG(INFO) << "SUPL: could not read Ref Time XML";
}
// Try to read Ref Location from XML
@@ -319,7 +378,7 @@ bool ControlThread::read_assistance_from_XML()
}
else
{
- LOG(INFO) << "SUPL: couldn't read Ref Location XML";
+ LOG(INFO) << "SUPL: could not read Ref Location XML";
}
}
@@ -332,11 +391,11 @@ void ControlThread::assist_GNSS()
//######### GNSS Assistance #################################
// GNSS Assistance configuration
bool enable_gps_supl_assistance = configuration_->property("GNSS-SDR.SUPL_gps_enabled", false);
- if (enable_gps_supl_assistance == true)
- //SUPL SERVER TEST. Not operational yet!
+ bool enable_agnss_xml = configuration_->property("GNSS-SDR.AGNSS_XML_enabled", false);
+ if ((enable_gps_supl_assistance == true) and (enable_agnss_xml == false))
{
std::cout << "SUPL RRLP GPS assistance enabled!" << std::endl;
- std::string default_acq_server = "supl.nokia.com";
+ std::string default_acq_server = "supl.google.com";
std::string default_eph_server = "supl.google.com";
supl_client_ephemeris_.server_name = configuration_->property("GNSS-SDR.SUPL_gps_ephemeris_server", default_acq_server);
supl_client_acquisition_.server_name = configuration_->property("GNSS-SDR.SUPL_gps_acquisition_server", default_eph_server);
@@ -372,6 +431,7 @@ void ControlThread::assist_GNSS()
if (read_assistance_from_XML())
{
std::cout << "GNSS assistance data loaded from local XML file(s)." << std::endl;
+ std::cout << "No SUPL request has been performed." << std::endl;
}
}
else
@@ -379,7 +439,7 @@ void ControlThread::assist_GNSS()
// Request ephemeris from SUPL server
int error;
supl_client_ephemeris_.request = 1;
- std::cout << "SUPL: Try to read GPS ephemeris from SUPL server..." << std::endl;
+ std::cout << "SUPL: Try to read GPS ephemeris data from SUPL server..." << std::endl;
error = supl_client_ephemeris_.get_assistance(supl_mcc, supl_mns, supl_lac, supl_ci);
if (error == 0)
{
@@ -388,35 +448,35 @@ void ControlThread::assist_GNSS()
gps_eph_iter != supl_client_ephemeris_.gps_ephemeris_map.cend();
gps_eph_iter++)
{
- std::cout << "SUPL: Received Ephemeris for GPS SV " << gps_eph_iter->first << std::endl;
+ std::cout << "SUPL: Received ephemeris data for satellite " << Gnss_Satellite("GPS", gps_eph_iter->second.i_satellite_PRN) << std::endl;
std::shared_ptr tmp_obj = std::make_shared(gps_eph_iter->second);
flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
}
- //Save ephemeris to XML file
+ // Save ephemeris to XML file
std::string eph_xml_filename = configuration_->property("GNSS-SDR.SUPL_gps_ephemeris_xml", eph_default_xml_filename);
if (supl_client_ephemeris_.save_ephemeris_map_xml(eph_xml_filename, supl_client_ephemeris_.gps_ephemeris_map) == true)
{
- std::cout << "SUPL: XML Ephemeris file created" << std::endl;
+ std::cout << "SUPL: XML ephemeris data file created" << std::endl;
}
else
{
- std::cout << "SUPL: Failed to create XML Ephemeris file" << std::endl;
+ std::cout << "SUPL: Failed to create XML ephemeris data file" << std::endl;
}
}
else
{
- std::cout << "ERROR: SUPL client for Ephemeris returned " << error << std::endl;
- std::cout << "Please check internet connection and SUPL server configuration" << error << std::endl;
- std::cout << "Trying to read ephemeris from XML file" << std::endl;
+ std::cout << "ERROR: SUPL client request for ephemeris data returned " << error << std::endl;
+ std::cout << "Please check your network connectivity and SUPL server configuration" << std::endl;
+ std::cout << "Trying to read AGNSS data from local XML file(s)..." << std::endl;
if (read_assistance_from_XML() == false)
{
- std::cout << "ERROR: Could not read Ephemeris file: Disabling SUPL assistance." << std::endl;
+ std::cout << "ERROR: Could not read XML files: Disabling SUPL assistance." << std::endl;
}
}
- // Request almanac , IONO and UTC Model
+ // Request almanac, IONO and UTC Model data
supl_client_ephemeris_.request = 0;
- std::cout << "SUPL: Try read Almanac, Iono, Utc Model, Ref Time and Ref Location from SUPL server..." << std::endl;
+ std::cout << "SUPL: Try to read Almanac, Iono, Utc Model, Ref Time and Ref Location data from SUPL server..." << std::endl;
error = supl_client_ephemeris_.get_assistance(supl_mcc, supl_mns, supl_lac, supl_ci);
if (error == 0)
{
@@ -425,33 +485,51 @@ void ControlThread::assist_GNSS()
gps_alm_iter != supl_client_ephemeris_.gps_almanac_map.cend();
gps_alm_iter++)
{
- std::cout << "SUPL: Received Almanac for GPS SV " << gps_alm_iter->first << std::endl;
+ std::cout << "SUPL: Received almanac data for satellite " << Gnss_Satellite("GPS", gps_alm_iter->second.i_satellite_PRN) << std::endl;
std::shared_ptr tmp_obj = std::make_shared(gps_alm_iter->second);
flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
}
if (supl_client_ephemeris_.gps_iono.valid == true)
{
- std::cout << "SUPL: Received GPS Iono" << std::endl;
+ std::cout << "SUPL: Received GPS Ionosphere model parameters" << std::endl;
std::shared_ptr tmp_obj = std::make_shared(supl_client_ephemeris_.gps_iono);
flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
}
if (supl_client_ephemeris_.gps_utc.valid == true)
{
- std::cout << "SUPL: Received GPS UTC Model" << std::endl;
+ std::cout << "SUPL: Received GPS UTC model parameters" << std::endl;
std::shared_ptr tmp_obj = std::make_shared(supl_client_ephemeris_.gps_utc);
flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
}
+ // Save iono and UTC model data to xml file
+ std::string iono_xml_filename = configuration_->property("GNSS-SDR.SUPL_gps_iono_xml", iono_default_xml_filename);
+ if (supl_client_ephemeris_.save_iono_xml(iono_xml_filename, supl_client_ephemeris_.gps_iono) == true)
+ {
+ std::cout << "SUPL: Iono data file created" << std::endl;
+ }
+ else
+ {
+ std::cout << "SUPL: Failed to create Iono data file" << std::endl;
+ }
+ std::string utc_xml_filename = configuration_->property("GNSS-SDR.SUPL_gps_utc_model.xml", utc_default_xml_filename);
+ if (supl_client_ephemeris_.save_utc_xml(utc_xml_filename, supl_client_ephemeris_.gps_utc) == true)
+ {
+ std::cout << "SUPL: UTC model data file created" << std::endl;
+ }
+ else
+ {
+ std::cout << "SUPL: Failed to create UTC model data file" << std::endl;
+ }
}
else
{
- std::cout << "ERROR: SUPL client for Almanac returned " << error << std::endl;
- std::cout << "Please check internet connection and SUPL server configuration" << error << std::endl;
- std::cout << "Disabling SUPL assistance." << std::endl;
+ std::cout << "ERROR: SUPL client for almanac data returned " << error << std::endl;
+ std::cout << "Please check your network connectivity and SUPL server configuration" << std::endl;
}
// Request acquisition assistance
supl_client_acquisition_.request = 2;
- std::cout << "SUPL: Try read Acquisition assistance from SUPL server..." << std::endl;
+ std::cout << "SUPL: Try to read acquisition assistance data from SUPL server..." << std::endl;
error = supl_client_acquisition_.get_assistance(supl_mcc, supl_mns, supl_lac, supl_ci);
if (error == 0)
{
@@ -460,30 +538,39 @@ void ControlThread::assist_GNSS()
gps_acq_iter != supl_client_acquisition_.gps_acq_map.cend();
gps_acq_iter++)
{
- std::cout << "SUPL: Received Acquisition assistance for GPS SV " << gps_acq_iter->first << std::endl;
+ std::cout << "SUPL: Received acquisition assistance data for satellite " << Gnss_Satellite("GPS", gps_acq_iter->second.i_satellite_PRN) << std::endl;
global_gps_acq_assist_map.write(gps_acq_iter->second.i_satellite_PRN, gps_acq_iter->second);
}
if (supl_client_acquisition_.gps_ref_loc.valid == true)
{
- std::cout << "SUPL: Received Ref Location (Acquisition Assistance)" << std::endl;
+ std::cout << "SUPL: Received Ref Location data (Acquisition Assistance)" << std::endl;
std::shared_ptr tmp_obj = std::make_shared(supl_client_acquisition_.gps_ref_loc);
flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
}
if (supl_client_acquisition_.gps_time.valid == true)
{
- std::cout << "SUPL: Received Ref Time (Acquisition Assistance)" << std::endl;
+ std::cout << "SUPL: Received Ref Time data (Acquisition Assistance)" << std::endl;
std::shared_ptr tmp_obj = std::make_shared(supl_client_acquisition_.gps_time);
flowgraph_->send_telemetry_msg(pmt::make_any(tmp_obj));
}
}
else
{
- std::cout << "ERROR: SUPL client for Acquisition assistance returned " << error << std::endl;
- std::cout << "Please check internet connection and SUPL server configuration" << error << std::endl;
- std::cout << "Disabling SUPL assistance.." << std::endl;
+ std::cout << "ERROR: SUPL client for acquisition assistance returned " << error << std::endl;
+ std::cout << "Please check your network connectivity and SUPL server configuration" << std::endl;
+ std::cout << "Disabling SUPL acquisition assistance." << std::endl;
}
}
}
+
+ if ((enable_gps_supl_assistance == false) and (enable_agnss_xml == true))
+ {
+ // read assistance from file
+ if (read_assistance_from_XML())
+ {
+ std::cout << "GNSS assistance data loaded from local XML file(s)." << std::endl;
+ }
+ }
}
diff --git a/src/core/receiver/control_thread.h b/src/core/receiver/control_thread.h
index b978b7757..7335d0547 100644
--- a/src/core/receiver/control_thread.h
+++ b/src/core/receiver/control_thread.h
@@ -171,6 +171,9 @@ private:
const std::string eph_cnav_default_xml_filename = "./gps_cnav_ephemeris.xml";
const std::string gal_iono_default_xml_filename = "./gal_iono.xml";
const std::string gal_utc_default_xml_filename = "./gal_utc_model.xml";
+ const std::string cnav_utc_default_xml_filename = "./gps_cnav_utc_model.xml";
+ const std::string eph_glo_gnav_default_xml_filename = "./glo_gnav_ephemeris.xml";
+ const std::string glo_utc_default_xml_filename = "./glo_utc_model.xml";
};
#endif /*GNSS_SDR_CONTROL_THREAD_H_*/
diff --git a/src/core/system_parameters/galileo_utc_model.h b/src/core/system_parameters/galileo_utc_model.h
index a4448ab19..53e930880 100644
--- a/src/core/system_parameters/galileo_utc_model.h
+++ b/src/core/system_parameters/galileo_utc_model.h
@@ -80,6 +80,7 @@ public:
archive& make_nvp("WN_LSF_6", WN_LSF_6);
archive& make_nvp("DN_6", DN_6);
archive& make_nvp("Delta_tLSF_6", Delta_tLSF_6);
+ archive& make_nvp("flag_utc_model", flag_utc_model);
}
};
diff --git a/src/core/system_parameters/gps_cnav_navigation_message.cc b/src/core/system_parameters/gps_cnav_navigation_message.cc
index 98d02d59d..642695469 100644
--- a/src/core/system_parameters/gps_cnav_navigation_message.cc
+++ b/src/core/system_parameters/gps_cnav_navigation_message.cc
@@ -391,5 +391,6 @@ bool Gps_CNAV_Navigation_Message::have_new_utc_model() // Check if we have a ne
Gps_CNAV_Utc_Model Gps_CNAV_Navigation_Message::get_utc_model()
{
+ utc_model_record.valid = true;
return utc_model_record;
}
diff --git a/src/tests/system-tests/libs/CMakeLists.txt b/src/tests/system-tests/libs/CMakeLists.txt
index 0fe1d4440..4742e80fc 100644
--- a/src/tests/system-tests/libs/CMakeLists.txt
+++ b/src/tests/system-tests/libs/CMakeLists.txt
@@ -25,6 +25,7 @@ set(SYSTEM_TESTING_LIB_SOURCES
include_directories(
${CMAKE_CURRENT_SOURCE_DIR}
+ ${Boost_INCLUDE_DIRS}
${GLOG_INCLUDE_DIRS}
${GFlags_INCLUDE_DIRS}
${MATIO_INCLUDE_DIRS}
diff --git a/src/tests/unit-tests/signal-processing-blocks/libs/CMakeLists.txt b/src/tests/unit-tests/signal-processing-blocks/libs/CMakeLists.txt
index 332f0e583..7d15075f2 100644
--- a/src/tests/unit-tests/signal-processing-blocks/libs/CMakeLists.txt
+++ b/src/tests/unit-tests/signal-processing-blocks/libs/CMakeLists.txt
@@ -29,6 +29,7 @@ set(SIGNAL_PROCESSING_TESTING_LIB_SOURCES
include_directories(
${CMAKE_CURRENT_SOURCE_DIR}
+ ${Boost_INCLUDE_DIRS}
${GLOG_INCLUDE_DIRS}
${GFlags_INCLUDE_DIRS}
${MATIO_INCLUDE_DIRS}
diff --git a/src/utils/rinex2assist/main.cc b/src/utils/rinex2assist/main.cc
index 86243ed7d..71b4b97fc 100644
--- a/src/utils/rinex2assist/main.cc
+++ b/src/utils/rinex2assist/main.cc
@@ -132,6 +132,7 @@ int main(int argc, char** argv)
gal_utc_model.WN_LSF_6 = hdr.leapWeek;
gal_utc_model.DN_6 = hdr.leapDay;
gal_utc_model.Delta_tLSF_6 = hdr.leapDelta;
+ gal_utc_model.flag_utc_model = (hdr.mapTimeCorr["GAUT"].A0 == 0.0);
gal_iono.ai0_5 = hdr.mapIonoCorr["GAL"].param[0];
gal_iono.ai1_5 = hdr.mapIonoCorr["GAL"].param[1];
gal_iono.ai2_5 = hdr.mapIonoCorr["GAL"].param[2];
@@ -242,7 +243,7 @@ int main(int argc, char** argv)
std::ofstream ofs;
if (xml_filename.empty())
{
- xml_filename = "eph_GPS_L1CA.xml";
+ xml_filename = "gps_ephemeris.xml";
}
try
{
@@ -261,12 +262,12 @@ int main(int argc, char** argv)
if (j != 0)
{
std::ofstream ofs2;
- xml_filename = "eph_Galileo_E1.xml";
+ xml_filename = "gal_ephemeris.xml";
try
{
ofs2.open(xml_filename.c_str(), std::ofstream::trunc | std::ofstream::out);
boost::archive::xml_oarchive xml(ofs2);
- xml << boost::serialization::make_nvp("GNSS-SDR_ephemeris_map", eph_gal_map);
+ xml << boost::serialization::make_nvp("GNSS-SDR_gal_ephemeris_map", eph_gal_map);
}
catch (std::exception& e)
{
@@ -281,12 +282,12 @@ int main(int argc, char** argv)
if (gps_utc_model.valid)
{
std::ofstream ofs3;
- xml_filename = "gps_utc.xml";
+ xml_filename = "gps_utc_model.xml";
try
{
ofs3.open(xml_filename.c_str(), std::ofstream::trunc | std::ofstream::out);
boost::archive::xml_oarchive xml(ofs3);
- xml << boost::serialization::make_nvp("GNSS-SDR_gps_utc", gps_utc_model);
+ xml << boost::serialization::make_nvp("GNSS-SDR_utc_model", gps_utc_model);
}
catch (std::exception& e)
{
@@ -306,7 +307,7 @@ int main(int argc, char** argv)
{
ofs4.open(xml_filename.c_str(), std::ofstream::trunc | std::ofstream::out);
boost::archive::xml_oarchive xml(ofs4);
- xml << boost::serialization::make_nvp("GNSS-SDR_gps_iono", gps_iono);
+ xml << boost::serialization::make_nvp("GNSS-SDR_iono_model", gps_iono);
}
catch (std::exception& e)
{
@@ -320,12 +321,12 @@ int main(int argc, char** argv)
if (gal_utc_model.A0_6 != 0)
{
std::ofstream ofs5;
- xml_filename = "gal_utc.xml";
+ xml_filename = "gal_utc_model.xml";
try
{
ofs5.open(xml_filename.c_str(), std::ofstream::trunc | std::ofstream::out);
boost::archive::xml_oarchive xml(ofs5);
- xml << boost::serialization::make_nvp("GNSS-SDR_gal_utc", gal_utc_model);
+ xml << boost::serialization::make_nvp("GNSS-SDR_gal_utc_model", gal_utc_model);
}
catch (std::exception& e)
{
@@ -343,7 +344,7 @@ int main(int argc, char** argv)
{
ofs7.open(xml_filename.c_str(), std::ofstream::trunc | std::ofstream::out);
boost::archive::xml_oarchive xml(ofs7);
- xml << boost::serialization::make_nvp("GNSS-SDR_gal_iono", gal_iono);
+ xml << boost::serialization::make_nvp("GNSS-SDR_gal_iono_model", gal_iono);
}
catch (std::exception& e)
{
diff --git a/src/core/libs/gnss_sdr_supl_client.h b/src/core/libs/gnss_sdr_supl_client.h
index 14aa4fdc2..465e552f3 100644
--- a/src/core/libs/gnss_sdr_supl_client.h
+++ b/src/core/libs/gnss_sdr_supl_client.h
@@ -43,6 +43,7 @@ extern "C"
#include "gps_iono.h"
#include "gps_almanac.h"
#include "gps_utc_model.h"
+#include "gps_cnav_utc_model.h"
#include "gps_acq_assist.h"
#include "gps_ref_time.h"
#include "gps_ref_location.h"
@@ -50,6 +51,8 @@ extern "C"
#include "galileo_ephemeris.h"
#include "galileo_utc_model.h"
#include "galileo_iono.h"
+#include "glonass_gnav_ephemeris.h"
+#include "glonass_gnav_utc_model.h"
#include
#include
#include
@@ -83,6 +86,8 @@ public:
std::map gps_ephemeris_map;
std::map gal_ephemeris_map;
std::map gps_cnav_ephemeris_map;
+ std::map glonass_gnav_ephemeris_map;
+
// almanac map
std::map gps_almanac_map;
@@ -94,6 +99,8 @@ public:
// UTC model
Gps_Utc_Model gps_utc;
Galileo_Utc_Model gal_utc;
+ Gps_CNAV_Utc_Model gps_cnav_utc;
+ Glonass_Gnav_Utc_Model glo_gnav_utc;
// reference location
Gps_Ref_Location gps_ref_loc;
// Acquisition Assistance map
@@ -119,54 +126,104 @@ public:
*/
bool load_ephemeris_xml(const std::string file_name);
+ /*!
+ * \brief Save ephemeris map to XML file.
+ */
+ bool save_ephemeris_map_xml(const std::string file_name,
+ std::map eph_map);
+
/*!
* \brief Read GPS CNAV ephemeris map from XML file
*/
bool load_cnav_ephemeris_xml(const std::string file_name);
+ /*!
+ * \brief Save GPS CNAV ephemeris map to XML file.
+ */
+ bool save_cnav_ephemeris_map_xml(const std::string file_name,
+ std::map eph_map);
+
/*!
* \brief Read Galileo ephemeris map from XML file
*/
bool load_gal_ephemeris_xml(const std::string file_name);
/*!
* \brief Save ephemeris map to XML file.
*/
- bool save_ephemeris_map_xml(const std::string file_name,
- std::map eph_map);
+ bool save_gal_ephemeris_map_xml(const std::string file_name,
+ std::map eph_map);
+
+ /*!
+ * \brief Read GLONASS GNAV ephemeris map from XML file
+ */
+ bool load_gnav_ephemeris_xml(const std::string file_name);
+
+ /*!
+ * \brief Save GLONASS GNAV ephemeris map to XML file.
+ */
+ bool save_gnav_ephemeris_map_xml(const std::string file_name,
+ std::map eph_map);
/*!
* \brief Read GPS utc model from XML file
*/
bool load_utc_xml(const std::string file_name);
+ /*!
+ * \brief Save UTC model map to XML file
+ */
+ bool save_utc_xml(const std::string file_name, Gps_Utc_Model& utc);
+
+ /*!
+ * \brief Read CNAV GPS utc model from XML file
+ */
+ bool load_cnav_utc_xml(const std::string file_name);
+
+ /*!
+ * \brief Save CNAV UTC model map to XML file
+ */
+ bool save_cnav_utc_xml(const std::string file_name, Gps_CNAV_Utc_Model& utc);
+
/*!
* \brief Read Galileo utc model from XML file
*/
bool load_gal_utc_xml(const std::string file_name);
/*!
- * \brief Save utc model map to XML file
- * To be called by ControlThread::gps_utc_model_data_write_to_XML()
+ * \brief Save Galileo UTC model map to XML file
*/
- bool save_utc_map_xml(const std::string file_name,
- std::map utc_map);
+ bool save_gal_utc_xml(const std::string file_name, Galileo_Utc_Model& utc);
/*!
* \brief Read iono from XML file
*/
bool load_iono_xml(const std::string file_name);
+ /*!
+ * \brief Save iono map to XML file
+ */
+ bool save_iono_xml(const std::string file_name, Gps_Iono& iono);
+
/*!
* \brief Read Galileo iono from XML file
*/
bool load_gal_iono_xml(const std::string file_name);
/*!
* \brief Save iono map to XML file
*/
- bool save_iono_map_xml(const std::string file_name,
- std::map iono_map);
+ bool save_gal_iono_xml(const std::string file_name, Galileo_Iono& iono);
+
+ /*!
+ * \brief Read Glonass utc model from XML file
+ */
+ bool load_glo_utc_xml(const std::string file_name);
+
+ /*!
+ * \brief Save Glonass UTC model map to XML file
+ */
+ bool save_glo_utc_xml(const std::string file_name, Glonass_Gnav_Utc_Model& utc);
/*!
* \brief Read ref time from XML file
@@ -194,6 +251,7 @@ public:
* Prints SUPL data to std::cout. Use it for debug purposes only.
*/
void print_assistance();
+
gnss_sdr_supl_client();
~gnss_sdr_supl_client();
};
@@ -119,54 +126,104 @@ public:
bool load_gal_ephemeris_xml(const std::string file_name);
/*!
- * \brief Save ephemeris map to XML file.
+ * \brief Save Galileo ephemeris map to XML file.
*/
@@ -119,54 +126,104 @@ public:
bool load_gal_iono_xml(const std::string file_name);
/*!
- * \brief Save iono map to XML file
+ * \brief Save Galileo iono map to XML file
*/